"use client";

import { cn } from "@/lib/utils";
import { usePathname, useRouter, useSearchParams } from "next/navigation";
import { forwardRef, ReactNode, useEffect, useImperativeHandle, useState } from "react";

interface Tab {
	label: {
		en: string;
		ar: string;
	};
	content: ReactNode;
}

interface TabsProps {
	tabs: Tab[];
	locale: string;
	className?: string;
}

export interface TabsRef {
	setActiveTab: (index: number) => void;
}

const Tabs = forwardRef<TabsRef, TabsProps>(({ tabs, locale, className }, ref) => {
	const [activeTab, setActiveTab] = useState(0);
	const router = useRouter();
	const pathname = usePathname();
	const searchParams = useSearchParams();

	// Initialize active tab from URL parameter
	useEffect(() => {
		const tabParam = searchParams.get("tab");
		if (tabParam) {
			const tabIndex = parseInt(tabParam, 10);
			if (!isNaN(tabIndex) && tabIndex >= 0 && tabIndex < tabs.length) {
				setActiveTab(tabIndex);
			}
		}
	}, [searchParams, tabs.length]);

	useImperativeHandle(ref, () => ({
		setActiveTab: (index: number) => {
			setActiveTab(index);
			updateUrlWithTab(index);
		}
	}));

	const updateUrlWithTab = (index: number) => {
		const params = new URLSearchParams(searchParams.toString());
		params.set("tab", index.toString());
		const newUrl = pathname + (params.toString() ? `?${params.toString()}` : "");
		window.history.pushState({}, "", newUrl);
	};

	const handleTabClick = (index: number) => {
		setActiveTab(index);
		updateUrlWithTab(index);
	};

	return (
		<div className={cn("w-full", className)}>
			<div className="mb-4 flex border-b border-gray-200">
				{tabs.map((tab, index) => (
					<button
						key={index}
						onClick={() => handleTabClick(index)}
						className={cn(
							"px-4 py-2 text-sm font-medium transition-colors",
							"hover:text-primary focus:outline-none",
							activeTab === index
								? "border-b-2 border-primary text-primary"
								: "text-gray-500"
						)}
					>
						{tab?.label[locale as keyof typeof tab.label]}
					</button>
				))}
			</div>
			<div className="mt-4">{tabs[activeTab]?.content}</div>
		</div>
	);
});

Tabs.displayName = "Tabs";

export default Tabs; 